@@ -8,16 +8,17 @@ from pyceg.Multiprocessor.MSI import MSI
 from pyceg.Multiprocessor.MESI import MESI
 from pyceg.Multiprocessor.MOESI import MOESI
 
-protocols = {"VI": VI, "MSI": MSI, "MESI": MESI, "MOESI": MESI}
+protocols = {"VI": VI, "MSI": MSI, "MESI": MESI, "MOESI": MOESI}
 
 simulation_parameters = {
-    # "Reads",
-    # "Writes",
     "Bus Transactions",
     "States",
-    "Invalidations",
     "Cache-to-Cache Transfers",
-    "Cache Misses"
+    "Cache Misses",
+    "Flushes",
+    # "Reads",
+    # "Writes",
+    # "Invalidations",
 }
 
 
