@@ -7,16 +7,10 @@ from pyceg.Multiprocessor.Operations import MSIOps as Ops
 ###################
 # MOESI Protocol
 ###################
-
-
 class MOESI(Protocol):
     def __init__(self, n_processors=2, memory_content=None):
         super(MOESI, self).__init__(n_processors, memory_content)
 
-    # MESI Extensions
-    def all_processors_are_invalid(self):
-        return all(p.state == State.I for p in self.processors)
-
     def on_event(self, pid, event, function):
         super().on_event(pid, event, function)
         state, transaction = self.get_processor_state(pid), None
@@ -71,27 +65,8 @@ class MOESI(Protocol):
         # Set State
         self.set_processor_state(pid, state)
 
-        # Processor Write to Cache using an Operation
-        if event == Ops.PrWr:
-            self.perform_processor_operation(pid, function)
-
-        # Self Invalidate
-        if event == Ops.PrInv:
-            self.set_processor_state(pid, "I")
-            self.set_processor_cache_content(pid, None)
-
-        # Invalidate copy
-        if event in (Ops.BusUpgr, Ops.BusRdX):
-            self.set_processor_cache_content(pid, None)
-
-        # If the new state is modified, store the modified value
-        if state == State.M:
-            self.modified_value = self.get_processor_cache_content(pid)
-
-        # Processor Read/Write from Memory
-        if event in (Ops.PrRd, Ops.PrWr):
-            cache_content = self.modified_value or self.memory_content
-            self.set_processor_cache_content(pid, cache_content)
+        # Perform Post Event Logic, to set Processor's Cache and Memory Content
+        super().on_post_event(pid=pid, event=event, function=function)
 
         return transaction
 
@@ -110,10 +85,29 @@ def example1():
     ]
     moesi = MOESI(n_processors=4, memory_content=0)
     moesi.perform_instructions(instructions)
-    moesi.print(_filter="transaction")
+    # moesi.print(_filter="transaction")
+
+
+######################
+# Example 2
+######################
+def example2():
+    instructions = [
+        (1, Ops.PrRd),
+        (2, Ops.PrRd),
+        (3, Ops.PrWr, lambda a: a + 2),
+        # (2, Ops.PrWr, lambda a: a + 2),
+        # (1, Ops.PrWr, lambda a: a + 2),
+        # (1, Ops.PrRd),
+    ]
+    moesi = MOESI(n_processors=3, memory_content=1)
+    moesi.perform_instructions(instructions)
+    # moesi.print(_filter="transaction")
+
 
 ###################
 # Main
 ###################
 # example1()
 # example2()
+# example2()
