@@ -7,7 +7,6 @@ from pyceg.Multiprocessor.Operations import VIOps as Ops
 ######################################
 # Two State Protocol (VI Write Through)
 ######################################
-
 class VI(Protocol):
     def __init__(self, n_processors=2, memory_content=None):
         super(VI, self).__init__(n_processors, memory_content)
@@ -35,27 +34,8 @@ class VI(Protocol):
         # Set State
         self.set_processor_state(pid, state)
 
-        # Processor Write to Cache using an Operation
-        if event == Ops.PrWr:
-            self.perform_processor_operation(pid, function)
-
-        # Self Invalidate
-        if event == Ops.PrInv:
-            self.set_processor_state(pid, "I")
-            self.set_processor_cache_content(pid, None)
-
-        # If the new state is modified, store the modified value
-        if state == State.V:
-            self.modified_value = self.get_processor_cache_content(pid)
-
-        # Processor Read/Write from Memory
-        if event in (Ops.PrRd, Ops.PrWr):
-            if self.modified_value:
-                cache_content = self.modified_value
-                self.memory_content = cache_content  # Updates Memory Content
-            else:
-                cache_content = self.memory_content
-            self.set_processor_cache_content(pid, cache_content)
+        # Perform Post Event Logic, to set Processor's Cache and Memory Content
+        super().on_post_event(pid=pid, event=event, function=function)
 
         return transaction
 
